.. pymadng documentation master file, created by
   sphinx-quickstart on Mon Nov 28 12:54:22 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. PyMAD-NG documentation master file

Welcome to the PyMAD-NG documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Getting Started

   intro
   installation
   quickstartguide

.. toctree::
   :maxdepth: 2
   :caption: Core Concepts

   communication
   function_reference
   architecture

.. toctree::
   :maxdepth: 2
   :caption: Advanced Topics

   advanced_features
   debugging

.. toctree::
   :maxdepth: 2
   :caption: Examples

   ex-lhc-couplingLocal
   examples

.. toctree::
   :maxdepth: 2
   :caption: Reference

   reference
   developer
   contributing


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
